@@ -74,7 +74,6 @@
 
 #include "kis_assert.h"
 
-#include <limits>
 #include "KoOdfGradientBackground.h"
 #include <KisHandlePainterHelper.h>
 
@@ -200,7 +199,7 @@ void KoShapePrivate::shapeChanged(KoShape::ChangeType type)
     }
 
     Q_FOREACH (KoShape::ShapeChangeListener *listener, listeners) {
-       listener->notifyShapeChangedImpl(type, q);
+        listener->notifyShapeChangedImpl(type, q);
     }
 }
 
@@ -217,74 +216,78 @@ void KoShapePrivate::removeShapeManager(KoShapeManager *manager)
 void KoShapePrivate::convertFromShapeCoordinates(KoConnectionPoint &point, const QSizeF &shapeSize) const
 {
     switch(point.alignment) {
-        case KoConnectionPoint::AlignNone:
-            point.position = KoFlake::toRelative(point.position, shapeSize);
-            point.position.rx() = qBound<qreal>(0.0, point.position.x(), 1.0);
-            point.position.ry() = qBound<qreal>(0.0, point.position.y(), 1.0);
-            break;
-        case KoConnectionPoint::AlignRight:
-            point.position.rx() -= shapeSize.width();
-        case KoConnectionPoint::AlignLeft:
-            point.position.ry() = 0.5*shapeSize.height();
-            break;
-        case KoConnectionPoint::AlignBottom:
-            point.position.ry() -= shapeSize.height();
-        case KoConnectionPoint::AlignTop:
-            point.position.rx() = 0.5*shapeSize.width();
-            break;
-        case KoConnectionPoint::AlignTopLeft:
-            // nothing to do here
-            break;
-        case KoConnectionPoint::AlignTopRight:
-            point.position.rx() -= shapeSize.width();
-            break;
-        case KoConnectionPoint::AlignBottomLeft:
-            point.position.ry() -= shapeSize.height();
-            break;
-        case KoConnectionPoint::AlignBottomRight:
-            point.position.rx() -= shapeSize.width();
-            point.position.ry() -= shapeSize.height();
-            break;
-        case KoConnectionPoint::AlignCenter:
-            point.position.rx() -= 0.5 * shapeSize.width();
-            point.position.ry() -= 0.5 * shapeSize.height();
-            break;
+    case KoConnectionPoint::AlignNone:
+        point.position = KoFlake::toRelative(point.position, shapeSize);
+        point.position.rx() = qBound<qreal>(0.0, point.position.x(), 1.0);
+        point.position.ry() = qBound<qreal>(0.0, point.position.y(), 1.0);
+        break;
+    case KoConnectionPoint::AlignRight:
+        point.position.rx() -= shapeSize.width();
+        break;
+    case KoConnectionPoint::AlignLeft:
+        point.position.ry() = 0.5*shapeSize.height();
+        break;
+    case KoConnectionPoint::AlignBottom:
+        point.position.ry() -= shapeSize.height();
+        break;
+    case KoConnectionPoint::AlignTop:
+        point.position.rx() = 0.5*shapeSize.width();
+        break;
+    case KoConnectionPoint::AlignTopLeft:
+        // nothing to do here
+        break;
+    case KoConnectionPoint::AlignTopRight:
+        point.position.rx() -= shapeSize.width();
+        break;
+    case KoConnectionPoint::AlignBottomLeft:
+        point.position.ry() -= shapeSize.height();
+        break;
+    case KoConnectionPoint::AlignBottomRight:
+        point.position.rx() -= shapeSize.width();
+        point.position.ry() -= shapeSize.height();
+        break;
+    case KoConnectionPoint::AlignCenter:
+        point.position.rx() -= 0.5 * shapeSize.width();
+        point.position.ry() -= 0.5 * shapeSize.height();
+        break;
     }
 }
 
 void KoShapePrivate::convertToShapeCoordinates(KoConnectionPoint &point, const QSizeF &shapeSize) const
 {
     switch(point.alignment) {
-        case KoConnectionPoint::AlignNone:
-            point.position = KoFlake::toAbsolute(point.position, shapeSize);
-            break;
-        case KoConnectionPoint::AlignRight:
-            point.position.rx() += shapeSize.width();
-        case KoConnectionPoint::AlignLeft:
-            point.position.ry() = 0.5*shapeSize.height();
-            break;
-        case KoConnectionPoint::AlignBottom:
-            point.position.ry() += shapeSize.height();
-        case KoConnectionPoint::AlignTop:
-            point.position.rx() = 0.5*shapeSize.width();
-            break;
-        case KoConnectionPoint::AlignTopLeft:
-            // nothing to do here
-            break;
-        case KoConnectionPoint::AlignTopRight:
-            point.position.rx() += shapeSize.width();
-            break;
-        case KoConnectionPoint::AlignBottomLeft:
-            point.position.ry() += shapeSize.height();
-            break;
-        case KoConnectionPoint::AlignBottomRight:
-            point.position.rx() += shapeSize.width();
-            point.position.ry() += shapeSize.height();
-            break;
-        case KoConnectionPoint::AlignCenter:
-            point.position.rx() += 0.5 * shapeSize.width();
-            point.position.ry() += 0.5 * shapeSize.height();
-            break;
+    case KoConnectionPoint::AlignNone:
+        point.position = KoFlake::toAbsolute(point.position, shapeSize);
+        break;
+    case KoConnectionPoint::AlignRight:
+        point.position.rx() += shapeSize.width();
+        break;
+    case KoConnectionPoint::AlignLeft:
+        point.position.ry() = 0.5*shapeSize.height();
+        break;
+    case KoConnectionPoint::AlignBottom:
+        point.position.ry() += shapeSize.height();
+        break;
+    case KoConnectionPoint::AlignTop:
+        point.position.rx() = 0.5*shapeSize.width();
+        break;
+    case KoConnectionPoint::AlignTopLeft:
+        // nothing to do here
+        break;
+    case KoConnectionPoint::AlignTopRight:
+        point.position.rx() += shapeSize.width();
+        break;
+    case KoConnectionPoint::AlignBottomLeft:
+        point.position.ry() += shapeSize.height();
+        break;
+    case KoConnectionPoint::AlignBottomRight:
+        point.position.rx() += shapeSize.width();
+        point.position.ry() += shapeSize.height();
+        break;
+    case KoConnectionPoint::AlignCenter:
+        point.position.rx() += 0.5 * shapeSize.width();
+        point.position.ry() += 0.5 * shapeSize.height();
+        break;
     }
 }
 
@@ -564,13 +567,21 @@ bool KoShape::compareShapeZIndex(KoShape *s1, KoShape *s2)
      *          zIndex are **merged**, while in Krita the contents of groups
      *          is never merged. One group will always below than the other.
      *          Therefore, when zIndex of two groups inside the same parent
-     *          coinside, the resulting painting order in Krita is
+     *          coincide, the resulting painting order in Krita is
      *          **UNDEFINED**.
      *
      *          To avoid this trouble we use  KoShapeReorderCommand::mergeInShape()
      *          inside KoShapeCreateCommand.
      */
 
+    /**
+     * The algorithm below doesn't correctly handle the case when the two pointers actually
+     * point to the same shape. So just check it in advance to guarantee strict weak ordering
+     * relation requirement
+     */
+    if (s1 == s2) return false;
+
+
     // First sort according to runThrough which is sort of a master level
     KoShape *parentShapeS1 = s1->parent();
     KoShape *parentShapeS2 = s2->parent();
@@ -941,22 +952,22 @@ bool KoShape::setConnectionPoint(int connectionPointId, const KoConnectionPoint
     const bool insertPoint = !hasConnectionPoint(connectionPointId);
 
     switch(connectionPointId) {
-        case KoConnectionPoint::TopConnectionPoint:
-        case KoConnectionPoint::RightConnectionPoint:
-        case KoConnectionPoint::BottomConnectionPoint:
-        case KoConnectionPoint::LeftConnectionPoint:
-        {
-            KoConnectionPoint::PointId id = static_cast<KoConnectionPoint::PointId>(connectionPointId);
-            d->connectors[id] = KoConnectionPoint::defaultConnectionPoint(id);
-            break;
-        }
-        default:
-        {
-            KoConnectionPoint p = point;
-            d->convertFromShapeCoordinates(p, size());
-            d->connectors[connectionPointId] = p;
-            break;
-        }
+    case KoConnectionPoint::TopConnectionPoint:
+    case KoConnectionPoint::RightConnectionPoint:
+    case KoConnectionPoint::BottomConnectionPoint:
+    case KoConnectionPoint::LeftConnectionPoint:
+    {
+        KoConnectionPoint::PointId id = static_cast<KoConnectionPoint::PointId>(connectionPointId);
+        d->connectors[id] = KoConnectionPoint::defaultConnectionPoint(id);
+        break;
+    }
+    default:
+    {
+        KoConnectionPoint p = point;
+        d->convertFromShapeCoordinates(p, size());
+        d->connectors[connectionPointId] = p;
+        break;
+    }
     }
 
     if(!insertPoint)
@@ -1518,46 +1529,46 @@ QString KoShape::saveStyle(KoGenStyle &style, KoShapeSavingContext &context) con
 
     QString wrap;
     switch (textRunAroundSide()) {
-        case BiggestRunAroundSide:
-            wrap = "biggest";
-            break;
-        case LeftRunAroundSide:
-            wrap = "left";
-            break;
-        case RightRunAroundSide:
-            wrap = "right";
-            break;
-        case EnoughRunAroundSide:
-            wrap = "dynamic";
-            break;
-        case BothRunAroundSide:
-            wrap = "parallel";
-            break;
-        case NoRunAround:
-            wrap = "none";
-            break;
-        case RunThrough:
-            wrap = "run-through";
-            break;
+    case BiggestRunAroundSide:
+        wrap = "biggest";
+        break;
+    case LeftRunAroundSide:
+        wrap = "left";
+        break;
+    case RightRunAroundSide:
+        wrap = "right";
+        break;
+    case EnoughRunAroundSide:
+        wrap = "dynamic";
+        break;
+    case BothRunAroundSide:
+        wrap = "parallel";
+        break;
+    case NoRunAround:
+        wrap = "none";
+        break;
+    case RunThrough:
+        wrap = "run-through";
+        break;
     }
     style.addProperty("style:wrap", wrap, KoGenStyle::GraphicType);
     switch (textRunAroundContour()) {
-        case ContourBox:
-            style.addProperty("style:wrap-contour", "false", KoGenStyle::GraphicType);
-            break;
-        case ContourFull:
-            style.addProperty("style:wrap-contour", "true", KoGenStyle::GraphicType);
-            style.addProperty("style:wrap-contour-mode", "full", KoGenStyle::GraphicType);
-            break;
-        case ContourOutside:
-            style.addProperty("style:wrap-contour", "true", KoGenStyle::GraphicType);
-            style.addProperty("style:wrap-contour-mode", "outside", KoGenStyle::GraphicType);
-            break;
+    case ContourBox:
+        style.addProperty("style:wrap-contour", "false", KoGenStyle::GraphicType);
+        break;
+    case ContourFull:
+        style.addProperty("style:wrap-contour", "true", KoGenStyle::GraphicType);
+        style.addProperty("style:wrap-contour-mode", "full", KoGenStyle::GraphicType);
+        break;
+    case ContourOutside:
+        style.addProperty("style:wrap-contour", "true", KoGenStyle::GraphicType);
+        style.addProperty("style:wrap-contour-mode", "outside", KoGenStyle::GraphicType);
+        break;
     }
     style.addPropertyPt("style:wrap-dynamic-threshold", textRunAroundThreshold(), KoGenStyle::GraphicType);
     if ((textRunAroundDistanceLeft() == textRunAroundDistanceRight())
-                && (textRunAroundDistanceTop() == textRunAroundDistanceBottom())
-                && (textRunAroundDistanceLeft() == textRunAroundDistanceTop())) {
+            && (textRunAroundDistanceTop() == textRunAroundDistanceBottom())
+            && (textRunAroundDistanceLeft() == textRunAroundDistanceTop())) {
         style.addPropertyPt("fo:margin", textRunAroundDistanceLeft(), KoGenStyle::GraphicType);
     } else {
         style.addPropertyPt("fo:margin-left", textRunAroundDistanceLeft(), KoGenStyle::GraphicType);
@@ -1985,7 +1996,7 @@ void KoShape::loadOdfGluePoints(const KoXmlElement &element, KoShapeLoadingConte
     }
     if (!hasCenterGluePoint) {
         d->connectors[d->connectors.count()] = KoConnectionPoint(QPointF(0.5, 0.5),
-                     KoConnectionPoint::AllDirections, KoConnectionPoint::AlignCenter);
+                                                                 KoConnectionPoint::AllDirections, KoConnectionPoint::AlignCenter);
     }
     debugFlake << "shape has now" << d->connectors.count() << "glue-points";
 }
@@ -2081,8 +2092,8 @@ QTransform KoShape::parseOdfTransform(const QString &transform)
             QTransform m;
             if (params.count() >= 6) {
                 m.setMatrix(params[0].toDouble(), params[1].toDouble(), 0,
-                            params[2].toDouble(), params[3].toDouble(), 0,
-                            KoUnit::parseValue(params[4]), KoUnit::parseValue(params[5]), 1);
+                        params[2].toDouble(), params[3].toDouble(), 0,
+                        KoUnit::parseValue(params[4]), KoUnit::parseValue(params[5]), 1);
             }
             matrix = matrix * m;
         }
@@ -2145,16 +2156,16 @@ void KoShape::saveOdfAttributes(KoShapeSavingContext &context, int attributes) c
             // TODO do this properly by subtracting rects
             s = parent()->size();
         }
-        context.xmlWriter().addAttributePt("svg:width", s.width());
-        context.xmlWriter().addAttributePt("svg:height", s.height());
+        context.xmlWriter().addAttribute("svg:width", s.width());
+        context.xmlWriter().addAttribute("svg:height", s.height());
     }
 
     // The position is implicitly stored in the transformation matrix
     // if the transformation is saved as well
     if ((attributes & OdfPosition) && !(attributes & OdfTransformation)) {
         const QPointF p(position() * context.shapeOffset(this));
-        context.xmlWriter().addAttributePt("svg:x", p.x());
-        context.xmlWriter().addAttributePt("svg:y", p.y());
+        context.xmlWriter().addAttribute("svg:x", p.x());
+        context.xmlWriter().addAttribute("svg:y", p.y());
     }
 
     if (attributes & OdfTransformation) {
@@ -2164,16 +2175,16 @@ void KoShape::saveOdfAttributes(KoShapeSavingContext &context, int attributes) c
                     && qAbs(matrix.m12()) < 1E-5        // 0
                     && qAbs(matrix.m21()) < 1E-5        // 0
                     && qAbs(matrix.m22() - 1) < 1E-5) { // 1
-                context.xmlWriter().addAttributePt("svg:x", matrix.dx());
-                context.xmlWriter().addAttributePt("svg:y", matrix.dy());
+                context.xmlWriter().addAttribute("svg:x", matrix.dx());
+                context.xmlWriter().addAttribute("svg:y", matrix.dy());
             } else {
                 QString m = QString("matrix(%1 %2 %3 %4 %5pt %6pt)")
-                            .arg(matrix.m11(), 0, 'f', 11)
-                            .arg(matrix.m12(), 0, 'f', 11)
-                            .arg(matrix.m21(), 0, 'f', 11)
-                            .arg(matrix.m22(), 0, 'f', 11)
-                            .arg(matrix.dx(), 0, 'f', 11)
-                            .arg(matrix.dy(), 0, 'f', 11);
+                        .arg(matrix.m11(), 0, 'f', 11)
+                        .arg(matrix.m12(), 0, 'f', 11)
+                        .arg(matrix.m21(), 0, 'f', 11)
+                        .arg(matrix.m22(), 0, 'f', 11)
+                        .arg(matrix.dx(), 0, 'f', 11)
+                        .arg(matrix.dy(), 0, 'f', 11);
                 context.xmlWriter().addAttribute("draw:transform", m);
             }
         }
@@ -2213,68 +2224,68 @@ void KoShape::saveOdfCommonChildElements(KoShapeSavingContext &context) const
                 context.xmlWriter().addAttribute("svg:x", QString("%1%").arg(x));
                 context.xmlWriter().addAttribute("svg:y", QString("%1%").arg(y));
             } else {
-                context.xmlWriter().addAttributePt("svg:x", cp.value().position.x());
-                context.xmlWriter().addAttributePt("svg:y", cp.value().position.y());
+                context.xmlWriter().addAttribute("svg:x", cp.value().position.x());
+                context.xmlWriter().addAttribute("svg:y", cp.value().position.y());
             }
             QString escapeDirection;
             switch(cp.value().escapeDirection) {
-                case KoConnectionPoint::HorizontalDirections:
-                    escapeDirection = "horizontal";
-                    break;
-                case KoConnectionPoint::VerticalDirections:
-                    escapeDirection = "vertical";
-                    break;
-                case KoConnectionPoint::LeftDirection:
-                    escapeDirection = "left";
-                    break;
-                case KoConnectionPoint::RightDirection:
-                    escapeDirection = "right";
-                    break;
-                case KoConnectionPoint::UpDirection:
-                    escapeDirection = "up";
-                    break;
-                case KoConnectionPoint::DownDirection:
-                    escapeDirection = "down";
-                    break;
-                default:
-                    // fall through
-                    break;
+            case KoConnectionPoint::HorizontalDirections:
+                escapeDirection = "horizontal";
+                break;
+            case KoConnectionPoint::VerticalDirections:
+                escapeDirection = "vertical";
+                break;
+            case KoConnectionPoint::LeftDirection:
+                escapeDirection = "left";
+                break;
+            case KoConnectionPoint::RightDirection:
+                escapeDirection = "right";
+                break;
+            case KoConnectionPoint::UpDirection:
+                escapeDirection = "up";
+                break;
+            case KoConnectionPoint::DownDirection:
+                escapeDirection = "down";
+                break;
+            default:
+                // fall through
+                break;
             }
             if(!escapeDirection.isEmpty()) {
                 context.xmlWriter().addAttribute("draw:escape-direction", escapeDirection);
             }
             QString alignment;
             switch(cp.value().alignment) {
-                case KoConnectionPoint::AlignTopLeft:
-                    alignment = "top-left";
-                    break;
-                case KoConnectionPoint::AlignTop:
-                    alignment = "top";
-                    break;
-                case KoConnectionPoint::AlignTopRight:
-                    alignment = "top-right";
-                    break;
-                case KoConnectionPoint::AlignLeft:
-                    alignment = "left";
-                    break;
-                case KoConnectionPoint::AlignCenter:
-                    alignment = "center";
-                    break;
-                case KoConnectionPoint::AlignRight:
-                    alignment = "right";
-                    break;
-                case KoConnectionPoint::AlignBottomLeft:
-                    alignment = "bottom-left";
-                    break;
-                case KoConnectionPoint::AlignBottom:
-                    alignment = "bottom";
-                    break;
-                case KoConnectionPoint::AlignBottomRight:
-                    alignment = "bottom-right";
-                    break;
-                default:
-                    // fall through
-                    break;
+            case KoConnectionPoint::AlignTopLeft:
+                alignment = "top-left";
+                break;
+            case KoConnectionPoint::AlignTop:
+                alignment = "top";
+                break;
+            case KoConnectionPoint::AlignTopRight:
+                alignment = "top-right";
+                break;
+            case KoConnectionPoint::AlignLeft:
+                alignment = "left";
+                break;
+            case KoConnectionPoint::AlignCenter:
+                alignment = "center";
+                break;
+            case KoConnectionPoint::AlignRight:
+                alignment = "right";
+                break;
+            case KoConnectionPoint::AlignBottomLeft:
+                alignment = "bottom-left";
+                break;
+            case KoConnectionPoint::AlignBottom:
+                alignment = "bottom";
+                break;
+            case KoConnectionPoint::AlignBottomRight:
+                alignment = "bottom-right";
+                break;
+            default:
+                // fall through
+                break;
             }
             if(!alignment.isEmpty()) {
                 context.xmlWriter().addAttribute("draw:align", alignment);
