@@ -46,7 +46,6 @@
 #include "kis_image_animation_interface.h"
 #include "kis_keyframe_channel.h"
 #include "kis_command_utils.h"
-#include "kis_processing_applicator.h"
 #include "commands_new/kis_change_projection_color_command.h"
 #include "kis_layer_properties_icons.h"
 #include "lazybrush/kis_colorize_mask.h"
@@ -54,6 +53,7 @@
 #include "commands/kis_node_compositeop_command.h"
 #include <KisDelayedUpdateNodeInterface.h>
 #include "krita_utils.h"
+#include "kis_image_signal_router.h"
 
 
 namespace KisLayerUtils {
@@ -1394,12 +1394,17 @@ namespace KisLayerUtils {
         mergeMultipleLayersImpl(image, mergedNodes, layer, true, kundo2_i18n("Flatten Layer"));
     }
 
-    void flattenImage(KisImageSP image)
+    void flattenImage(KisImageSP image, KisNodeSP activeNode)
     {
+        if (!activeNode) {
+            activeNode = image->root()->lastChild();
+        }
+
+
         KisNodeList mergedNodes;
         mergedNodes << image->root();
 
-        mergeMultipleLayersImpl(image, mergedNodes, 0, true, kundo2_i18n("Flatten Image"));
+        mergeMultipleLayersImpl(image, mergedNodes, activeNode, true, kundo2_i18n("Flatten Image"));
     }
 
     KisSimpleUpdateCommand::KisSimpleUpdateCommand(KisNodeList nodes, bool finalize, KUndo2Command *parent)
@@ -1418,17 +1423,6 @@ namespace KisLayerUtils {
         }
     }
 
-    void recursiveApplyNodes(KisNodeSP node, std::function<void(KisNodeSP)> func)
-    {
-        func(node);
-
-        node = node->firstChild();
-        while (node) {
-            recursiveApplyNodes(node, func);
-            node = node->nextSibling();
-        }
-    }
-
     KisNodeSP recursiveFindNode(KisNodeSP node, std::function<bool(KisNodeSP)> func)
     {
         if (func(node)) {
