@@ -36,10 +36,8 @@
 #include <QFile>
 #include <QLocale>
 #include <QMessageBox>
-#include <QMessageBox>
 #include <QProcessEnvironment>
 #include <QSettings>
-#include <QStandardPaths>
 #include <QStringList>
 #include <QStyle>
 #include <QStyleFactory>
@@ -56,12 +54,12 @@
 #include <KoPluginLoader.h>
 #include <KoShapeRegistry.h>
 #include <KoDpi.h>
-#include "KoGlobal.h"
 #include "KoConfig.h"
 #include <resources/KoHashGeneratorProvider.h>
 #include <KoResourcePaths.h>
 #include <KisMimeDatabase.h>
 #include "thememanager.h"
+#include "KisPrintJob.h"
 #include "KisDocument.h"
 #include "KisMainWindow.h"
 #include "KisAutoSaveRecoveryDialog.h"
@@ -93,17 +91,21 @@
 #include "kis_workspace_resource.h"
 
 #include <KritaVersionWrapper.h>
+#include <dialogs/KisSessionManagerDialog.h>
+
 namespace {
 const QTime appStartTime(QTime::currentTime());
 }
 
-class KisApplicationPrivate
+class KisApplication::Private
 {
 public:
-    KisApplicationPrivate()
-        : splashScreen(0)
-    {}
+    Private() {}
     QPointer<KisSplashScreen> splashScreen;
+    KisAutoSaveRecoveryDialog *autosaveDialog {0};
+    QPointer<KisMainWindow> mainWindow; // The first mainwindow we create on startup
+    bool batchRun {false};
+
 };
 
 class KisApplication::ResetStarting
@@ -117,27 +119,7 @@ public:
 
     ~ResetStarting()  {
         if (m_splash) {
-
-            KConfigGroup cfg( KSharedConfig::openConfig(), "SplashScreen");
-            bool hideSplash = cfg.readEntry("HideSplashAfterStartup", false);
-            if (m_fileCount > 0 || hideSplash) {
-                m_splash->hide();
-            }
-            else {
-                m_splash->setWindowFlags(Qt::Dialog);
-                QRect r(QPoint(), m_splash->size());
-                m_splash->move(QApplication::desktop()->availableGeometry().center() - r.center());
-                m_splash->setWindowTitle(qAppName());
-                m_splash->setParent(0);
-                Q_FOREACH (QObject *o, m_splash->children()) {
-                    QWidget *w = qobject_cast<QWidget*>(o);
-                    if (w && w->isHidden()) {
-                        w->setVisible(true);
-                    }
-                }
-                m_splash->show();
-                m_splash->activateWindow();
-            }
+            m_splash->hide();
         }
     }
 
@@ -148,10 +130,7 @@ public:
 
 KisApplication::KisApplication(const QString &key, int &argc, char **argv)
     : QtSingleApplication(key, argc, argv)
-    , d(new KisApplicationPrivate)
-    , m_autosaveDialog(0)
-    , m_mainWindow(0)
-    , m_batchRun(false)
+    , d(new Private)
 {
 #ifdef Q_OS_OSX
     setMouseCoalescingEnabled(false);
@@ -188,7 +167,6 @@ KisApplication::KisApplication(const QString &key, int &argc, char **argv)
     }
 
     KisOpenGL::initialize();
-    qDebug() << "krita has opengl" << KisOpenGL::hasOpenGL();
 }
 
 #if defined(Q_OS_WIN) && defined(ENV32BIT)
@@ -233,7 +211,6 @@ void KisApplication::addResourceTypes()
     // All Krita's resource types
     KoResourcePaths::addResourceType("kis_pics", "data", "/pics/");
     KoResourcePaths::addResourceType("kis_images", "data", "/images/");
-    KoResourcePaths::addResourceType("icc_profiles", "data", "/profiles/");
     KoResourcePaths::addResourceType("metadata_schema", "data", "/metadata/schemas/");
     KoResourcePaths::addResourceType("kis_brushes", "data", "/brushes/");
     KoResourcePaths::addResourceType("kis_taskset", "data", "/taskset/");
@@ -243,6 +220,8 @@ void KisApplication::addResourceTypes()
     KoResourcePaths::addResourceType("kis_defaultpresets", "data", "/defaultpresets/");
     KoResourcePaths::addResourceType("kis_paintoppresets", "data", "/paintoppresets/");
     KoResourcePaths::addResourceType("kis_workspaces", "data", "/workspaces/");
+    KoResourcePaths::addResourceType("kis_windowlayouts", "data", "/windowlayouts/");
+    KoResourcePaths::addResourceType("kis_sessions", "data", "/sessions/");
     KoResourcePaths::addResourceType("psd_layer_style_collections", "data", "/asl");
     KoResourcePaths::addResourceType("ko_patterns", "data", "/patterns/", true);
     KoResourcePaths::addResourceType("ko_gradients", "data", "/gradients/");
@@ -251,6 +230,7 @@ void KisApplication::addResourceTypes()
     KoResourcePaths::addResourceType("kis_shortcuts", "data", "/shortcuts/");
     KoResourcePaths::addResourceType("kis_actions", "data", "/actions");
     KoResourcePaths::addResourceType("icc_profiles", "data", "/color/icc");
+    KoResourcePaths::addResourceType("icc_profiles", "data", "/profiles/");
     KoResourcePaths::addResourceType("ko_effects", "data", "/effects/");
     KoResourcePaths::addResourceType("tags", "data", "/tags/");
     KoResourcePaths::addResourceType("templates", "data", "/templates");
@@ -287,9 +267,6 @@ void KisApplication::addResourceTypes()
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/preset_icons/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/preset_icons/tool_icons/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/preset_icons/emblem_icons/");
-
-    // Indicate that it is now safe for users of KoResourcePaths to load resources
-    KoResourcePaths::setReady();
 }
 
 void KisApplication::loadResources()
@@ -405,12 +382,12 @@ bool KisApplication::start(const KisApplicationArguments &args)
     const bool exportAs = args.exportAs();
     const QString exportFileName = args.exportFileName();
 
-    m_batchRun = (exportAs || !exportFileName.isEmpty());
+    d->batchRun = (exportAs || !exportFileName.isEmpty());
     const bool needsMainWindow = !exportAs;
     // only show the mainWindow when no command-line mode option is passed
-    const bool showmainWindow = !exportAs; // would be !batchRun;
+    bool showmainWindow = !exportAs; // would be !batchRun;
 
-    const bool showSplashScreen = !m_batchRun && qEnvironmentVariableIsEmpty("NOSPLASH");
+    const bool showSplashScreen = !d->batchRun && qEnvironmentVariableIsEmpty("NOSPLASH");
     if (showSplashScreen && d->splashScreen) {
         d->splashScreen->show();
         d->splashScreen->repaint();
@@ -419,9 +396,6 @@ bool KisApplication::start(const KisApplicationArguments &args)
 
     KoHashGeneratorProvider::instance()->setGenerator("MD5", new KisMD5Generator());
 
-    // Initialize all Krita directories etc.
-    KoGlobal::initialize();
-
     KConfigGroup group(KSharedConfig::openConfig(), "theme");
     Digikam::ThemeManager themeManager;
     themeManager.setCurrentTheme(group.readEntry("Theme", "Krita dark"));
@@ -446,39 +420,67 @@ bool KisApplication::start(const KisApplicationArguments &args)
     // Load the gui plugins
     loadGuiPlugins();
 
+    KisPart *kisPart = KisPart::instance();
     if (needsMainWindow) {
         // show a mainWindow asap, if we want that
         setSplashScreenLoadingText(i18n("Loading Main Window..."));
         processEvents();
-        m_mainWindow = KisPart::instance()->createMainWindow();
+
+
+        bool sessionNeeded = true;
+        auto sessionMode = cfg.sessionOnStartup();
+
+        if (!args.session().isEmpty()) {
+            sessionNeeded = !kisPart->restoreSession(args.session());
+        } else if (sessionMode == KisConfig::SOS_ShowSessionManager) {
+            showmainWindow = false;
+            sessionNeeded = false;
+            kisPart->showSessionManager();
+        } else if (sessionMode == KisConfig::SOS_PreviousSession) {
+            KConfigGroup sessionCfg = KSharedConfig::openConfig()->group("session");
+            const QString &sessionName = sessionCfg.readEntry("previousSession");
+
+            sessionNeeded = !kisPart->restoreSession(sessionName);
+        }
+
+        if (sessionNeeded) {
+            kisPart->startBlankSession();
+        }
+
+        if (!args.windowLayout().isEmpty()) {
+            KoResourceServer<KisWindowLayoutResource> * rserver = KisResourceServerProvider::instance()->windowLayoutServer();
+            KisWindowLayoutResource* windowLayout = rserver->resourceByName(args.windowLayout());
+            if (windowLayout) {
+                windowLayout->applyLayout();
+            }
+        }
 
         if (showmainWindow) {
-            m_mainWindow->initializeGeometry();
+            d->mainWindow = kisPart->currentMainwindow();
 
             if (!args.workspace().isEmpty()) {
                 KoResourceServer<KisWorkspaceResource> * rserver = KisResourceServerProvider::instance()->workspaceServer();
                 KisWorkspaceResource* workspace = rserver->resourceByName(args.workspace());
                 if (workspace) {
-                    m_mainWindow->restoreWorkspace(workspace);
+                    d->mainWindow->restoreWorkspace(workspace);
                 }
             }
 
             if (args.canvasOnly()) {
-                m_mainWindow->viewManager()->switchCanvasOnly(true);
+                d->mainWindow->viewManager()->switchCanvasOnly(true);
             }
 
             if (args.fullScreen()) {
-                m_mainWindow->showFullScreen();
-            }
-            else {
-                m_mainWindow->show();
+                d->mainWindow->showFullScreen();
             }
+        } else {
+            d->mainWindow = kisPart->createMainWindow();
         }
     }
     short int numberOfOpenDocuments = 0; // number of documents open
 
-    // Check for autosave files that can be restored, if we're not running a batchrun (test, export)
-    if (!m_batchRun) {
+    // Check for autosave files that can be restored, if we're not running a batchrun (test)
+    if (!d->batchRun) {
         checkAutosaveFiles();
     }
 
@@ -495,8 +497,8 @@ bool KisApplication::start(const KisApplicationArguments &args)
     if (doNewImage) {
         KisDocument *doc = args.image();
         if (doc) {
-            KisPart::instance()->addDocument(doc);
-            m_mainWindow->addViewAndNotifyLoadingCompleted(doc);
+            kisPart->addDocument(doc);
+            d->mainWindow->addViewAndNotifyLoadingCompleted(doc);
         }
     }
 
@@ -509,10 +511,10 @@ bool KisApplication::start(const KisApplicationArguments &args)
             // are we just trying to open a template?
             if (doTemplate) {
                 // called in mix with batch options? ignore and silently skip
-                if (m_batchRun) {
+                if (d->batchRun) {
                     continue;
                 }
-                if (createNewDocFromTemplate(fileName, m_mainWindow)) {
+                if (createNewDocFromTemplate(fileName, d->mainWindow)) {
                     ++numberOfOpenDocuments;
                 }
                 // now try to load
@@ -525,8 +527,8 @@ bool KisApplication::start(const KisApplicationArguments &args)
                         return 1;
                     }
 
-                    KisDocument *doc = KisPart::instance()->createDocument();
-                    doc->setFileBatchMode(m_batchRun);
+                    KisDocument *doc = kisPart->createDocument();
+                    doc->setFileBatchMode(d->batchRun);
                     doc->openUrl(QUrl::fromLocalFile(fileName));
 
                     qApp->processEvents(); // For vector layers to be updated
@@ -537,13 +539,14 @@ bool KisApplication::start(const KisApplicationArguments &args)
                     }
                     QTimer::singleShot(0, this, SLOT(quit()));
                 }
-                else if (m_mainWindow) {
+                else if (d->mainWindow) {
                     if (fileName.endsWith(".bundle")) {
-                        m_mainWindow->installBundle(fileName);
+                        d->mainWindow->installBundle(fileName);
                     }
                     else {
-                        KisMainWindow::OpenFlags flags = m_batchRun ? KisMainWindow::BatchMode : KisMainWindow::None;
-                        if (m_mainWindow->openDocument(QUrl::fromLocalFile(fileName), flags)) {
+                        KisMainWindow::OpenFlags flags = d->batchRun ? KisMainWindow::BatchMode : KisMainWindow::None;
+
+                        if (d->mainWindow->openDocument(QUrl::fromLocalFile(fileName), flags)) {
                             // Normal case, success
                             numberOfOpenDocuments++;
                         }
@@ -567,7 +570,6 @@ bool KisApplication::start(const KisApplicationArguments &args)
 
 KisApplication::~KisApplication()
 {
-    delete d;
 }
 
 void KisApplication::setSplashScreen(QWidget *splashScreen)
@@ -634,7 +636,7 @@ void KisApplication::remoteArguments(QByteArray message, QObject *socket)
                 createNewDocFromTemplate(filename, mw);
             }
             else if (QFile(filename).exists()) {
-                KisMainWindow::OpenFlags flags = m_batchRun ? KisMainWindow::BatchMode : KisMainWindow::None;
+                KisMainWindow::OpenFlags flags = d->batchRun ? KisMainWindow::BatchMode : KisMainWindow::None;
                 mw->openDocument(QUrl::fromLocalFile(filename), flags);
             }
         }
@@ -645,7 +647,7 @@ void KisApplication::fileOpenRequested(const QString &url)
 {
     KisMainWindow *mainWindow = KisPart::instance()->mainWindows().first();
     if (mainWindow) {
-        KisMainWindow::OpenFlags flags = m_batchRun ? KisMainWindow::BatchMode : KisMainWindow::None;
+        KisMainWindow::OpenFlags flags = d->batchRun ? KisMainWindow::BatchMode : KisMainWindow::None;
         mainWindow->openDocument(QUrl::fromLocalFile(url), flags);
     }
 }
@@ -653,7 +655,7 @@ void KisApplication::fileOpenRequested(const QString &url)
 
 void KisApplication::checkAutosaveFiles()
 {
-    if (m_batchRun) return;
+    if (d->batchRun) return;
 
     // Check for autosave files from a previous run. There can be several, and
     // we want to offer a restore for every one. Including a nice thumbnail!
@@ -676,11 +678,11 @@ void KisApplication::checkAutosaveFiles()
             // hide the splashscreen to see the dialog
             d->splashScreen->hide();
         }
-        m_autosaveDialog = new KisAutoSaveRecoveryDialog(autosaveFiles, activeWindow());
-        QDialog::DialogCode result = (QDialog::DialogCode) m_autosaveDialog->exec();
+        d->autosaveDialog = new KisAutoSaveRecoveryDialog(autosaveFiles, activeWindow());
+        QDialog::DialogCode result = (QDialog::DialogCode) d->autosaveDialog->exec();
 
         if (result == QDialog::Accepted) {
-            QStringList filesToRecover = m_autosaveDialog->recoverableFiles();
+            QStringList filesToRecover = d->autosaveDialog->recoverableFiles();
             Q_FOREACH (const QString &autosaveFile, autosaveFiles) {
                 if (!filesToRecover.contains(autosaveFile)) {
                     QFile::remove(dir.absolutePath() + "/" + autosaveFile);
@@ -697,16 +699,16 @@ void KisApplication::checkAutosaveFiles()
                 const QUrl url = QUrl::fromLocalFile(dir.absolutePath() + QLatin1Char('/') + autoSaveFile);
                 autosaveUrls << url;
             }
-            if (m_mainWindow) {
+            if (d->mainWindow) {
                 Q_FOREACH (const QUrl &url, autosaveUrls) {
-                    KisMainWindow::OpenFlags flags = m_batchRun ? KisMainWindow::BatchMode : KisMainWindow::None;
-                    m_mainWindow->openDocument(url, flags | KisMainWindow::RecoveryFile);
+                    KisMainWindow::OpenFlags flags = d->batchRun ? KisMainWindow::BatchMode : KisMainWindow::None;
+                    d->mainWindow->openDocument(url, flags | KisMainWindow::RecoveryFile);
                 }
             }
         }
         // cleanup
-        delete m_autosaveDialog;
-        m_autosaveDialog = nullptr;
+        delete d->autosaveDialog;
+        d->autosaveDialog = nullptr;
     }
 }
 
@@ -748,7 +750,7 @@ bool KisApplication::createNewDocFromTemplate(const QString &fileName, KisMainWi
         QUrl templateURL;
         templateURL.setPath(templateBase.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash).path() + '/' + templateName);
 
-        KisMainWindow::OpenFlags batchFlags = m_batchRun ? KisMainWindow::BatchMode : KisMainWindow::None;
+        KisMainWindow::OpenFlags batchFlags = d->batchRun ? KisMainWindow::BatchMode : KisMainWindow::None;
         if (mainWindow->openDocument(templateURL, KisMainWindow::Import | batchFlags)) {
             dbgUI << "Template loaded...";
             return true;
