@@ -30,11 +30,12 @@
 #include <KoColorSpaceEngine.h>
 #include <KoCanvasBase.h>
 #include <KoToolManager.h>
-#include <KoShapeBasedDocumentBase.h>
+#include <KoShapeControllerBase.h>
 #include <KoResourceServerProvider.h>
 #include <kis_icon.h>
 
 #include "KisApplication.h"
+#include "KisMainWindow.h"
 #include "KisDocument.h"
 #include "KisView.h"
 #include "KisViewManager.h"
@@ -57,26 +58,21 @@
 #include <QDomElement>
 #include <QGlobalStatic>
 #include <KisMimeDatabase.h>
+#include <dialogs/KisSessionManagerDialog.h>
 
-#include "KisView.h"
-#include "KisDocument.h"
 #include "kis_config.h"
 #include "kis_shape_controller.h"
 #include "KisResourceServerProvider.h"
 #include "kis_animation_cache_populator.h"
 #include "kis_idle_watcher.h"
 #include "kis_image.h"
-#include "KisImportExportManager.h"
-#include "KisDocument.h"
-#include "KoToolManager.h"
-#include "KisViewManager.h"
 #include "KisOpenPane.h"
 
 #include "kis_color_manager.h"
-#include "kis_debug.h"
 
 #include "kis_action.h"
 #include "kis_action_registry.h"
+#include "KisSessionResource.h"
 
 Q_GLOBAL_STATIC(KisPart, s_instance)
 
@@ -103,6 +99,20 @@ public:
     KActionCollection *actionCollection{0};
     KisIdleWatcher idleWatcher;
     KisAnimationCachePopulator animationCachePopulator;
+
+    KisSessionResource *currentSession = nullptr;
+    bool closingSession{false};
+    QScopedPointer<KisSessionManagerDialog> sessionManager;
+
+    bool queryCloseDocument(KisDocument *document) {
+        Q_FOREACH(auto view, views) {
+            if (view && view->isVisible() && view->document() == document) {
+                return view->queryClose();
+            }
+        }
+
+        return false;
+    }
 };
 
 
@@ -131,6 +141,7 @@ KisPart::KisPart()
     connect(&d->idleWatcher, SIGNAL(startedIdleMode()),
             &d->animationCachePopulator, SLOT(slotRequestRegeneration()));
 
+
     d->animationCachePopulator.slotRequestRegeneration();
 }
 
@@ -201,9 +212,9 @@ void KisPart::removeDocument(KisDocument *document)
     document->deleteLater();
 }
 
-KisMainWindow *KisPart::createMainWindow()
+KisMainWindow *KisPart::createMainWindow(QUuid id)
 {
-    KisMainWindow *mw = new KisMainWindow();
+    KisMainWindow *mw = new KisMainWindow(id);
     dbgUI <<"mainWindow" << (void*)mw << "added to view" << this;
     d->mainWindows.append(mw);
     emit sigWindowAdded(mw);
@@ -304,6 +315,50 @@ int KisPart::viewCount(KisDocument *doc) const
     }
 }
 
+bool KisPart::closingSession() const
+{
+    return d->closingSession;
+}
+
+bool KisPart::closeSession(bool keepWindows)
+{
+    d->closingSession = true;
+
+    Q_FOREACH(auto document, d->documents) {
+        if (!d->queryCloseDocument(document.data())) {
+            d->closingSession = false;
+            return false;
+        }
+    }
+
+    if (d->currentSession) {
+        KisConfig kisCfg;
+        if (kisCfg.saveSessionOnQuit(false)) {
+
+            d->currentSession->storeCurrentWindows();
+            d->currentSession->save();
+
+            KConfigGroup cfg = KSharedConfig::openConfig()->group("session");
+            cfg.writeEntry("previousSession", d->currentSession->name());
+        }
+
+        d->currentSession = nullptr;
+    }
+
+    if (!keepWindows) {
+        Q_FOREACH (auto window, d->mainWindows) {
+            window->close();
+        }
+
+        if (d->sessionManager) {
+            d->sessionManager->close();
+        }
+    }
+
+    d->closingSession = false;
+    return true;
+}
+
 void KisPart::slotDocumentSaved()
 {
     KisDocument *doc = qobject_cast<KisDocument*>(sender());
@@ -345,6 +400,16 @@ KisMainWindow *KisPart::currentMainwindow() const
 
 }
 
+KisMainWindow * KisPart::windowById(QUuid id) const
+{
+    Q_FOREACH(QPointer<KisMainWindow> mainWindow, d->mainWindows) {
+        if (mainWindow->id() == id) {
+            return mainWindow;
+        }
+    }
+
+    return nullptr;
+}
 
 KisIdleWatcher* KisPart::idleWatcher() const
 {
@@ -466,3 +531,38 @@ KisInputManager* KisPart::currentInputManager()
     return manager ? manager->inputManager() : 0;
 }
 
+void KisPart::showSessionManager()
+{
+    if (d->sessionManager.isNull()) {
+        d->sessionManager.reset(new KisSessionManagerDialog());
+    }
+
+    d->sessionManager->show();
+    d->sessionManager->activateWindow();
+}
+
+void KisPart::startBlankSession()
+{
+    KisMainWindow *window = createMainWindow();
+    window->initializeGeometry();
+    window->show();
+
+}
+
+bool KisPart::restoreSession(const QString &sessionName)
+{
+    if (sessionName.isNull()) return false;
+
+    KoResourceServer<KisSessionResource> * rserver = KisResourceServerProvider::instance()->sessionServer();
+    auto *session = rserver->resourceByName(sessionName);
+    if (!session || !session->valid()) return false;
+
+    session->restore();
+
+    return true;
+}
+
+void KisPart::setCurrentSession(KisSessionResource *session)
+{
+    d->currentSession = session;
+}
