@@ -42,7 +42,7 @@ class KisGridManager;
 class KisGuidesManager;
 class KisImageManager;
 class KisNodeManager;
-class KisPaintingAssistantsManager;
+class KisDecorationsManager;
 class KisPaintopBox;
 class KisSelectionManager;
 class KisStatusBar;
@@ -50,7 +50,6 @@ class KisUndoAdapter;
 class KisZoomManager;
 class KisPaintopBox;
 class KisActionManager;
-class KisScriptManager;
 class KisInputManager;
 class KoUpdater;
 class KoProgressUpdater;
@@ -164,8 +163,6 @@ public:  // Krita specific interfaces
 
     KisDocument *document() const;
 
-    KisScriptManager *scriptManager() const;
-
     int viewCount() const;
 
     /**
@@ -255,6 +252,7 @@ private Q_SLOTS:
     void guiUpdateTimeout();
     void changeAuthorProfile(const QString &profileName);
     void slotUpdateAuthorProfileActions();
+    void slotUpdatePixelGridAction();
     void slotSaveShowRulersState(bool value);
     void slotSaveRulersTrackMouseState(bool value);
 
