@@ -42,6 +42,7 @@
 #include "kis_time_range.h"
 #include "kis_keyframe_channel.h"
 #include "kis_raster_keyframe_channel.h"
+#include "kis_painter.h"
 
 namespace {
 QPointF getFittingOffset(QList<KoShape*> shapes,
@@ -226,7 +227,8 @@ void KisPasteActionFactory::run(bool pasteAtCursorPosition, KisViewManager *view
             rasterChannel->importFrame(range.start(), clip, 0);
             rasterChannel->addKeyframe(range.end() + 1, 0);
         } else {
-            newLayer->paintDevice()->makeCloneFromRough(clip, clip->extent());
+            const QRect rc = clip->extent();
+            KisPainter::copyAreaOptimized(rc.topLeft(), clip, newLayer->paintDevice(), rc);
         }
 
         KUndo2Command *cmd = new KisImageLayerAddCommand(image, newLayer, parentNode, aboveNode);
