@@ -249,6 +249,9 @@ void GeneralTab::setDefault()
     KoColor cursorColor(KoColorSpaceRegistry::instance()->rgb8());
     cursorColor.fromQColor(cfg.getCursorMainColor(true));
     cursorColorBtutton->setColor(cursorColor);
+
+
+
 }
 
 CursorStyle GeneralTab::cursorStyle()
@@ -462,7 +465,7 @@ ColorSettingsTab::ColorSettingsTab(QWidget *parent, const char *name)
         m_monitorProfileWidgets << cmb;
     }
 
-    refillMonitorProfiles(KoID("RGBA", ""));
+    refillMonitorProfiles(KoID("RGBA"));
 
     for(int i = 0; i < QApplication::desktop()->screenCount(); ++i) {
         if (m_monitorProfileWidgets[i]->contains(cfg.monitorProfile(i))) {
@@ -534,7 +537,7 @@ void ColorSettingsTab::installProfile()
     }
 
     KisConfig cfg;
-    refillMonitorProfiles(KoID("RGBA", ""));
+    refillMonitorProfiles(KoID("RGBA"));
 
     for(int i = 0; i < QApplication::desktop()->screenCount(); ++i) {
         if (m_monitorProfileWidgets[i]->contains(cfg.monitorProfile(i))) {
@@ -564,9 +567,8 @@ void ColorSettingsTab::toggleAllowMonitorProfileSelection(bool useSystemProfile)
         }
     }
     else {
+        refillMonitorProfiles(KoID("RGBA"));
         KisConfig cfg;
-        refillMonitorProfiles(KoID("RGBA", ""));
-
         for(int i = 0; i < QApplication::desktop()->screenCount(); ++i) {
             if (m_monitorProfileWidgets[i]->contains(cfg.monitorProfile(i))) {
                 m_monitorProfileWidgets[i]->setCurrent(cfg.monitorProfile(i));
@@ -579,7 +581,7 @@ void ColorSettingsTab::setDefault()
 {
     m_page->cmbWorkingColorSpace->setCurrent("RGBA");
 
-    refillMonitorProfiles(KoID("RGBA", ""));
+    refillMonitorProfiles(KoID("RGBA"));
 
     KisConfig cfg;
     KisImageConfig cfgImage;
@@ -1137,6 +1139,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     page->setObjectName("general");
     page->setHeader(i18n("General"));
     page->setIcon(KisIconUtils::loadIcon("go-home"));
+    m_pages << page;
     addPage(page);
     m_general = new GeneralTab(vbox);
 
@@ -1146,6 +1149,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     page->setObjectName("shortcuts");
     page->setHeader(i18n("Shortcuts"));
     page->setIcon(KisIconUtils::loadIcon("document-export"));
+    m_pages << page;
     addPage(page);
     m_shortcutSettings = new ShortcutSettingsTab(vbox);
     connect(this, SIGNAL(accepted()), m_shortcutSettings, SLOT(saveChanges()));
@@ -1157,6 +1161,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     page->setHeader(i18n("Canvas Input"));
     page->setObjectName("canvasinput");
     page->setIcon(KisIconUtils::loadIcon("configure"));
+    m_pages << page;
 
     // Display
     vbox = new KoVBox();
@@ -1164,6 +1169,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     page->setObjectName("display");
     page->setHeader(i18n("Display"));
     page->setIcon(KisIconUtils::loadIcon("preferences-desktop-display"));
+    m_pages << page;
     addPage(page);
     m_displaySettings = new DisplaySettingsTab(vbox);
 
@@ -1173,6 +1179,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     page->setObjectName("colormanagement");
     page->setHeader(i18n("Color"));
     page->setIcon(KisIconUtils::loadIcon("preferences-desktop-color"));
+    m_pages << page;
     addPage(page);
     m_colorSettings = new ColorSettingsTab(vbox);
 
@@ -1182,6 +1189,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     page->setObjectName("performance");
     page->setHeader(i18n("Performance"));
     page->setIcon(KisIconUtils::loadIcon("applications-system"));
+    m_pages << page;
     addPage(page);
     m_performanceSettings = new PerformanceTab(vbox);
 
@@ -1191,6 +1199,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     page->setObjectName("tablet");
     page->setHeader(i18n("Tablet"));
     page->setIcon(KisIconUtils::loadIcon("document-edit"));
+    m_pages << page;
     addPage(page);
     m_tabletSettings = new TabletSettingsTab(vbox);
 
@@ -1200,6 +1209,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     page->setObjectName("canvasonly");
     page->setHeader(i18n("Canvas-only"));
     page->setIcon(KisIconUtils::loadIcon("folder-pictures"));
+    m_pages << page;
     addPage(page);
     m_fullscreenSettings = new FullscreenSettingsTab(vbox);
 
@@ -1209,6 +1219,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     page->setObjectName("author");
     page->setHeader(i18n("Author"));
     page->setIcon(KisIconUtils::loadIcon("im-user"));
+    m_pages << page;
 
 
     QPushButton *restoreDefaultsButton = button(QDialogButtonBox::RestoreDefaults);
@@ -1232,13 +1243,22 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
         connect(this, SIGNAL(accepted()), preferenceSet, SLOT(savePreferences()), Qt::UniqueConnection);
     }
 
-
     connect(restoreDefaultsButton, SIGNAL(clicked(bool)), this, SLOT(slotDefault()));
 
+    KisConfig cfg;
+    QString currentPageName = cfg.readEntry<QString>("KisDlgPreferences/CurrentPage");
+    Q_FOREACH(KPageWidgetItem *page, m_pages) {
+        if (page->objectName() == currentPageName) {
+            setCurrentPage(page);
+            break;
+        }
+    }
 }
 
 KisDlgPreferences::~KisDlgPreferences()
 {
+    KisConfig cfg;
+    cfg.writeEntry<QString>("KisDlgPreferences/CurrentPage", currentPage()->objectName());
 }
 
 void KisDlgPreferences::slotDefault()
