@@ -24,6 +24,8 @@
 
 #include <QWidget>
 #include <QButtonGroup>
+#include <QMap>
+#include <QString>
 
 #include <kpagedialog.h>
 #include <kis_config.h>
@@ -339,6 +341,8 @@ protected:
     KisInputConfigurationPage *m_inputConfiguration;
     KoConfigAuthorPage *m_authorPage;
 
+    QList<KPageWidgetItem*> m_pages;
+
 protected Q_SLOTS:
 
     void slotDefault();
