@@ -106,6 +106,8 @@ public:
     KisNodeSelectionAdapter* nodeSelectionAdapter() const;
     KisNodeInsertionAdapter* nodeInsertionAdapter() const;
 
+    static bool isNodeHidden(KisNodeSP node, bool isGlobalSelectionHidden);
+
 public Q_SLOTS:
 
     /**
@@ -163,7 +165,7 @@ public Q_SLOTS:
     void toggleIsolateActiveNode();
     void toggleIsolateMode(bool checked);
     void slotUpdateIsolateModeAction();
-    void slotTryFinishIsolatedMode();
+    void slotTryRestartIsolatedMode();
 
     void moveNodeAt(KisNodeSP node, KisNodeSP parent, int index);
     void createNode(const QString& nodeType, bool quiet = false, KisPaintDeviceSP copyFrom = 0);
