@@ -58,7 +58,7 @@ KisPaintOpSettingsWidget::KisPaintOpSettingsWidget(QWidget * parent)
     setObjectName("KisPaintOpPresetsWidget");
 
     m_d->model       = new KisPaintOpOptionListModel(this);
-    m_d->optionsList = new KisCategorizedListView(false, this);
+    m_d->optionsList = new KisCategorizedListView(this);
     m_d->optionsList->setModel(m_d->model);
     m_d->optionsList->setItemDelegate(new KisCategorizedItemDelegate(m_d->optionsList));
     m_d->optionsList->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
@@ -84,10 +84,10 @@ KisPaintOpSettingsWidget::KisPaintOpSettingsWidget(QWidget * parent)
 
     connect(m_d->optionsList, SIGNAL(activated(const QModelIndex&)), this, SLOT(changePage(const QModelIndex&)));
     connect(m_d->optionsList, SIGNAL(clicked(QModelIndex)), this, SLOT(changePage(const QModelIndex&)));
-    connect(m_d->optionsList, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(lockProperties(const QModelIndex&)));
     connect(m_d->optionsList, SIGNAL(rightClickedMenuDropSettingsTriggered()), this, SLOT(slotLockPropertiesDrop()));
     connect(m_d->optionsList, SIGNAL(rightClickedMenuSaveSettingsTriggered()), this, SLOT(slotLockPropertiesSave()));
     connect(m_d->optionsList, SIGNAL(sigEntryChecked(QModelIndex)), this, SLOT(slotEntryChecked(QModelIndex)));
+    connect (m_d->optionsList, SIGNAL(lockAreaTriggered(QModelIndex)), this, SLOT(lockProperties(const QModelIndex&)));
 
 }
 
@@ -211,11 +211,13 @@ void KisPaintOpSettingsWidget::lockProperties(const QModelIndex& index)
             KisLockedPropertiesServer::instance()->addToLockedProperties(p);
             info.option->setLocked(true);
             m_d->model->categoriesMapper()->itemFromRow(index.row())->setLocked(true);
+
         }
         else {
             KisLockedPropertiesServer::instance()->removeFromLockedProperties(p);
             info.option->setLocked(false);
             m_d->model->categoriesMapper()->itemFromRow(index.row())->setLocked(false);
+
             if (m_saveLockedOption){
                 emit sigSaveLockedConfig(p);
             }
