@@ -257,7 +257,7 @@ void KisScratchPad::endPan(KoPointerEvent *event)
 void KisScratchPad::pick(KoPointerEvent *event)
 {
     KoColor color;
-    if (KisToolUtils::pick(m_paintLayer->projection(), event->point.toPoint(), &color)) {
+    if (KisToolUtils::pickColor(color, m_paintLayer->projection(), event->point.toPoint())) {
         emit colorSelected(color);
     }
 }
@@ -510,6 +510,7 @@ void KisScratchPad::fillLayer()
 {
     if(!m_paintLayer) return;
     KisPaintDeviceSP paintDevice = m_paintLayer->paintDevice();
+
     KisPainter painter(paintDevice);
     QRect sourceRect(0, 0, paintDevice->exactBounds().width(), paintDevice->exactBounds().height());
     painter.bitBlt(QPoint(0, 0), m_resourceProvider->currentImage()->projection(), sourceRect);
