@@ -74,7 +74,6 @@
 #include "kis_node_model.h"
 
 #include "canvas/kis_canvas2.h"
-#include "KisDocument.h"
 #include "kis_dummies_facade_base.h"
 #include "kis_shape_controller.h"
 #include "kis_selection_mask.h"
@@ -92,7 +91,6 @@
 #include "ui_wdglayerbox.h"
 
 #include <QProxyStyle>
-#include <QPainter>
 
 class KisLayerBoxStyle : public QProxyStyle
 {
@@ -745,26 +743,26 @@ inline bool isSelectionMask(KisNodeSP node)
 
 KisNodeSP KisLayerBox::findNonHidableNode(KisNodeSP startNode)
 {
-    if (isSelectionMask(startNode) &&
+    if (KisNodeManager::isNodeHidden(startNode, true) &&
             startNode->parent() &&
             !startNode->parent()->parent()) {
 
 
         KisNodeSP node = startNode->prevSibling();
-        while (node && isSelectionMask(node)) {
+        while (node && KisNodeManager::isNodeHidden(node, true)) {
             node = node->prevSibling();
         }
 
         if (!node) {
             node = startNode->nextSibling();
-            while (node && isSelectionMask(node)) {
+            while (node && KisNodeManager::isNodeHidden(node, true)) {
                 node = node->nextSibling();
             }
         }
 
         if (!node) {
             node = m_image->root()->lastChild();
-            while (node && isSelectionMask(node)) {
+            while (node && KisNodeManager::isNodeHidden(node, true)) {
                 node = node->prevSibling();
             }
         }
