@@ -26,7 +26,6 @@ class QIODevice;
 #include <QBuffer>
 
 #include <kis_annotation.h>
-#include <kis_debug.h>
 
 #include "psd.h"
 #include "psd_utils.h"
@@ -70,7 +69,7 @@ class PSDResourceBlock : public KisAnnotation
 public:
     PSDResourceBlock();
 
-    ~PSDResourceBlock()
+    ~PSDResourceBlock() override
     {
         delete resource;
     }
@@ -87,7 +86,7 @@ public:
         return copied;
     }
 
-    QString displayText() const {
+    QString displayText() const override {
         if (resource) {
             return resource->displayText();
         }
@@ -112,7 +111,7 @@ public:
 /* 0x03e9 - Optional - Mac print manager print info record */
 struct MAC_PRINT_INFO_1001 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading MAC_PRINT_INFO_1001";
         return true;
@@ -141,8 +140,8 @@ struct RESN_INFO_1005 : public PSDInterpretedResource
         , heightUnit(PSD_UNIT_INCH)
     {}
 
-    virtual bool interpretBlock(QByteArray data);
-    virtual bool createBlock(QByteArray & data);
+    bool interpretBlock(QByteArray data) override;
+    bool createBlock(QByteArray & data) override;
 
     Fixed   hRes;
     quint16 hResUnit;
@@ -157,7 +156,7 @@ struct RESN_INFO_1005 : public PSDInterpretedResource
 /* 0x03ee - Alpha channel names */
 struct ALPHA_NAMES_1006 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading ALPHA_NAMES_1006";
 
@@ -169,7 +168,7 @@ struct ALPHA_NAMES_1006 : public PSDInterpretedResource
 /* 0x03ef - DisplayInfo structure */
 struct DISPLAY_INFO_1007 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading DISPLAY_INFO_1007";
         return true;
@@ -180,7 +179,7 @@ struct DISPLAY_INFO_1007 : public PSDInterpretedResource
 /* 0x03f0 - Optional - Caption string */
 struct CAPTION_1008 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading CAPTION_1008";
         return true;
@@ -191,7 +190,7 @@ struct CAPTION_1008 : public PSDInterpretedResource
 /* 0x03f1 - Border info */
 struct BORDER_INFO_1009 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading BORDER_INFO_1009";
         return true;
@@ -203,7 +202,7 @@ struct BORDER_INFO_1009 : public PSDInterpretedResource
 /* 0x03f2 - Background colour */
 struct BACKGROUND_COL_1010 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading BACKGROUND_COL_1010";
         return true;
@@ -214,7 +213,7 @@ struct BACKGROUND_COL_1010 : public PSDInterpretedResource
 /* 0x03f3 - Print flags */
 struct PRINT_FLAGS_1011 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading PRINT_FLAGS_1011";
         return true;
@@ -225,7 +224,7 @@ struct PRINT_FLAGS_1011 : public PSDInterpretedResource
 /* 0x03f4 - Greyscale and multichannel halftoning info */
 struct GREY_HALFTONE_1012 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading GREY_HALFTONE_1012";
         return true;
@@ -236,7 +235,7 @@ struct GREY_HALFTONE_1012 : public PSDInterpretedResource
 /* 0x03f5 - Colour halftoning info */
 struct COLOR_HALFTONE_1013 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading COLOR_HALFTONE_1013";
         return true;
@@ -247,7 +246,7 @@ struct COLOR_HALFTONE_1013 : public PSDInterpretedResource
 /* 0x03f6 - Duotone halftoning info */
 struct DUOTONE_HALFTONE_1014 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading DUOTONE_HALFTONE_1014";
         return true;
@@ -258,7 +257,7 @@ struct DUOTONE_HALFTONE_1014 : public PSDInterpretedResource
 /* 0x03f7 - Greyscale and multichannel transfer functions */
 struct GREY_XFER_1015 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading GREY_XFER_1015";
         return true;
@@ -269,7 +268,7 @@ struct GREY_XFER_1015 : public PSDInterpretedResource
 /* 0x03f8 - Colour transfer functions */
 struct COLOR_XFER_1016 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading COLOR_XFER_1016";
         return true;
@@ -280,7 +279,7 @@ struct COLOR_XFER_1016 : public PSDInterpretedResource
 /* 0x03f9 - Duotone transfer functions */
 struct DUOTONE_XFER_1017 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading DUOTONE_XFER_1017";
         return true;
@@ -291,7 +290,7 @@ struct DUOTONE_XFER_1017 : public PSDInterpretedResource
 /* 0x03fa - Duotone image information */
 struct DUOTONE_INFO_1018 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading DUOTONE_INFO_1018";
         return true;
@@ -302,7 +301,7 @@ struct DUOTONE_INFO_1018 : public PSDInterpretedResource
 /* 0x03fb - Effective black & white values for dot range */
 struct EFFECTIVE_BW_1019 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading EFFECTIVE_BW_1019";
         return true;
@@ -313,7 +312,7 @@ struct EFFECTIVE_BW_1019 : public PSDInterpretedResource
 /* 0x03fd - EPS options */
 struct EPS_OPT_1021 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading EPS_OPT_1021";
         return true;
@@ -323,7 +322,7 @@ struct EPS_OPT_1021 : public PSDInterpretedResource
 
 /* 0x03fe - Quick mask info */
 struct QUICK_MASK_1022 : public PSDInterpretedResource
-{    bool interpretBlock(QByteArray /*data*/)
+{    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading QUICK_MASK_1022";
         return true;
@@ -334,7 +333,7 @@ struct QUICK_MASK_1022 : public PSDInterpretedResource
 /* 0x0400 - Layer state info */
 struct LAYER_STATE_1024 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading LAYER_STATE_1024";
         return true;
@@ -345,7 +344,7 @@ struct LAYER_STATE_1024 : public PSDInterpretedResource
 /* 0x0401 - Working path (not saved) */
 struct WORKING_PATH_1025 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
 {
     dbgFile << "Reading WORKING_PATH_1025";
     return true;
@@ -356,7 +355,7 @@ struct WORKING_PATH_1025 : public PSDInterpretedResource
 /* 0x0402 - Layers group info */
 struct LAYER_GROUP_1026 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading LAYER_GROUP_1026";
         return true;
@@ -367,7 +366,7 @@ struct LAYER_GROUP_1026 : public PSDInterpretedResource
 /* 0x0404 - IPTC-NAA record (IMV4.pdf) */
 struct IPTC_NAA_DATA_1028 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading IPTC_NAA_DATA_1028";
         return true;
@@ -378,7 +377,7 @@ struct IPTC_NAA_DATA_1028 : public PSDInterpretedResource
 /* 0x0405 - Image mode for raw format files */
 struct IMAGE_MODE_RAW_1029 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading IMAGE_MODE_RAW_1029";
         return true;
@@ -389,7 +388,7 @@ struct IMAGE_MODE_RAW_1029 : public PSDInterpretedResource
 /* 0x0406 - JPEG quality */
 struct JPEG_QUAL_1030 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading JPEG_QUAL_1030";
         return true;
@@ -400,7 +399,7 @@ struct JPEG_QUAL_1030 : public PSDInterpretedResource
 /* 0x0408 - Grid & guide info */
 struct GRID_GUIDE_1032 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading GRID_GUIDE_1032";
         return true;
@@ -411,7 +410,7 @@ struct GRID_GUIDE_1032 : public PSDInterpretedResource
 /* 0x0409 - Thumbnail resource */
 struct THUMB_RES_1033 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading THUMB_RES_1033";
         return true;
@@ -422,7 +421,7 @@ struct THUMB_RES_1033 : public PSDInterpretedResource
 /* 0x040a - Copyright flag */
 struct COPYRIGHT_FLG_1034 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading COPYRIGHT_FLG_1034";
         return true;
@@ -433,7 +432,7 @@ struct COPYRIGHT_FLG_1034 : public PSDInterpretedResource
 /* 0x040b - URL string */
 struct URL_1035 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading URL_1035";
         return true;
@@ -444,7 +443,7 @@ struct URL_1035 : public PSDInterpretedResource
 /* 0x040c - Thumbnail resource */
 struct THUMB_RES2_1036 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading THUMB_RES2_1036";
         return true;
@@ -460,7 +459,7 @@ struct GLOBAL_ANGLE_1037 : public PSDInterpretedResource
         : angle(30)
     {}
 
-    bool interpretBlock(QByteArray data)
+    bool interpretBlock(QByteArray data) override
     {
         dbgFile << "Reading GLOBAL_ANGLE_1037";
 
@@ -472,7 +471,7 @@ struct GLOBAL_ANGLE_1037 : public PSDInterpretedResource
         return true;
     }
 
-    virtual bool createBlock(QByteArray & data)
+    bool createBlock(QByteArray & data) override
     {
         QBuffer buf(&data);
         startBlock(buf, PSDImageResourceSection::GLOBAL_ANGLE, 4);
@@ -480,9 +479,9 @@ struct GLOBAL_ANGLE_1037 : public PSDInterpretedResource
         return true;
     }
 
-    virtual bool valid() { return true; }
+    bool valid() override { return true; }
 
-    virtual QString displayText() { return QString("Global Angle: %1").arg(angle); }
+    QString displayText() override { return QString("Global Angle: %1").arg(angle); }
 
     qint32 angle;
 };
@@ -491,7 +490,7 @@ struct GLOBAL_ANGLE_1037 : public PSDInterpretedResource
 /* 0x040e - Colour samplers resource */
 struct COLOR_SAMPLER_1038 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading COLOR_SAMPLER_1038";
         return true;
@@ -502,8 +501,8 @@ struct COLOR_SAMPLER_1038 : public PSDInterpretedResource
 /* 0x040f - ICC Profile */
 struct ICC_PROFILE_1039 : public PSDInterpretedResource
 {
-    virtual bool interpretBlock(QByteArray data);
-    virtual bool createBlock(QByteArray & data);
+    bool interpretBlock(QByteArray data) override;
+    bool createBlock(QByteArray & data) override;
 
     QByteArray icc;
 };
@@ -512,7 +511,7 @@ struct ICC_PROFILE_1039 : public PSDInterpretedResource
 /* 0x0410 - Watermark */
 struct WATERMARK_1040 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading WATERMARK_1040";
         return true;
@@ -523,7 +522,7 @@ struct WATERMARK_1040 : public PSDInterpretedResource
 /* 0x0411 - Do not use ICC profile flag */
 struct ICC_UNTAGGED_1041 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading ICC_UNTAGGED_1041";
         return true;
@@ -534,7 +533,7 @@ struct ICC_UNTAGGED_1041 : public PSDInterpretedResource
 /* 0x0412 - Show / hide all effects layers */
 struct EFFECTS_VISIBLE_1042 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading EFFECTS_VISIBLE_1042";
         return true;
@@ -545,7 +544,7 @@ struct EFFECTS_VISIBLE_1042 : public PSDInterpretedResource
 /* 0x0413 - Spot halftone */
 struct SPOT_HALFTONE_1043 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading SPOT_HALFTONE_1043";
         return true;
@@ -556,7 +555,7 @@ struct SPOT_HALFTONE_1043 : public PSDInterpretedResource
 /* 0x0414 - Document specific IDs */
 struct DOC_IDS_1044 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading DOC_IDS_1044";
         return true;
@@ -567,7 +566,7 @@ struct DOC_IDS_1044 : public PSDInterpretedResource
 /* 0x0415 - Unicode alpha names */
 struct ALPHA_NAMES_UNI_1045 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading ALPHA_NAMES_UNI_1045";
         return true;
@@ -578,7 +577,7 @@ struct ALPHA_NAMES_UNI_1045 : public PSDInterpretedResource
 /* 0x0416 - Indexed colour table count */
 struct IDX_COL_TAB_CNT_1046 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading IDX_COL_TAB_CNT_1046";
         return true;
@@ -589,7 +588,7 @@ struct IDX_COL_TAB_CNT_1046 : public PSDInterpretedResource
 /* 0x0417 - Index of transparent colour (if any) */
 struct IDX_TRANSPARENT_1047 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading IDX_TRANSPARENT_1047";
         return true;
@@ -603,7 +602,7 @@ struct GLOBAL_ALT_1049 : public PSDInterpretedResource
     GLOBAL_ALT_1049()
         : altitude(30)
     {}
-    bool interpretBlock(QByteArray data)
+    bool interpretBlock(QByteArray data) override
     {
         dbgFile << "Reading GLOBAL_ALT_1049";
         QDataStream ds(data);
@@ -612,7 +611,7 @@ struct GLOBAL_ALT_1049 : public PSDInterpretedResource
         return true;
     }
 
-    virtual bool createBlock(QByteArray & data)
+    bool createBlock(QByteArray & data) override
     {
         QBuffer buf(&data);
         startBlock(buf, PSDImageResourceSection::GLOBAL_ALT, 4);
@@ -620,9 +619,9 @@ struct GLOBAL_ALT_1049 : public PSDInterpretedResource
         return true;
     }
 
-    virtual bool valid() { return true; }
+    bool valid() override { return true; }
 
-    virtual QString displayText() { return QString("Global Altitude: %1").arg(altitude); }
+    QString displayText() override { return QString("Global Altitude: %1").arg(altitude); }
 
     qint32 altitude;
 };
@@ -631,7 +630,7 @@ struct GLOBAL_ALT_1049 : public PSDInterpretedResource
 /* 0x041a - Slices */
 struct SLICES_1050 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading SLICES_1050";
         return true;
@@ -642,7 +641,7 @@ struct SLICES_1050 : public PSDInterpretedResource
 /* 0x041b - Workflow URL - Unicode string */
 struct WORKFLOW_URL_UNI_1051 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading WORKFLOW_URL_UNI_1051";
         return true;
@@ -653,7 +652,7 @@ struct WORKFLOW_URL_UNI_1051 : public PSDInterpretedResource
 /* 0x041c - Jump to XPEP (?) */
 struct JUMP_TO_XPEP_1052 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "JUMP_TO_XPEP_1052";
         return true;
@@ -664,7 +663,7 @@ struct JUMP_TO_XPEP_1052 : public PSDInterpretedResource
 /* 0x041d - Alpha IDs */
 struct ALPHA_ID_1053 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "ALPHA_ID_1053";
         return true;
@@ -674,7 +673,7 @@ struct ALPHA_ID_1053 : public PSDInterpretedResource
 /* 0x041e - URL list - unicode */
 struct URL_LIST_UNI_1054 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "URL_LIST_UNI_1054";
         return true;
@@ -684,7 +683,7 @@ struct URL_LIST_UNI_1054 : public PSDInterpretedResource
 /* 0x0421 - Version info */
 struct VERSION_INFO_1057 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "VERSION_INFO_1057";
         return true;
@@ -695,7 +694,7 @@ struct VERSION_INFO_1057 : public PSDInterpretedResource
 /* 0x0422 - Exif data block */
 struct EXIF_DATA_1058 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading EXIF_DATA_1058";
         return true;
@@ -706,7 +705,7 @@ struct EXIF_DATA_1058 : public PSDInterpretedResource
 /* 0x0424 - XMP data block */
 struct XMP_DATA_1060 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading XMP_DATA_1060";
         return true;
@@ -717,7 +716,7 @@ struct XMP_DATA_1060 : public PSDInterpretedResource
 /* 0x07d0 - First path info block */
 struct PATH_INFO_FIRST_2000 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "PATH_INFO_FIRST_2000";
         return true;
@@ -728,7 +727,7 @@ struct PATH_INFO_FIRST_2000 : public PSDInterpretedResource
 /* 0x0bb6 - Last path info block */
 struct PATH_INFO_LAST_2998 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "PATH_INFO_LAST_2998";
         return true;
@@ -739,7 +738,7 @@ struct PATH_INFO_LAST_2998 : public PSDInterpretedResource
 /* 0x0bb7 - Name of clipping path */
 struct CLIPPING_PATH_2999 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading CLIPPING_PATH_2999";
         return true;
@@ -750,7 +749,7 @@ struct CLIPPING_PATH_2999 : public PSDInterpretedResource
 /* 0x2710 - Print flags */
 struct PRINT_FLAGS_2_10000 : public PSDInterpretedResource
 {
-    bool interpretBlock(QByteArray /*data*/)
+    bool interpretBlock(QByteArray /*data*/) override
     {
         dbgFile << "Reading PRINT_FLAGS_2_10000";
         return true;
